@@ -1,6 +1,6 @@
 package POE::Component::Client::HTTP;
 {
-  $POE::Component::Client::HTTP::VERSION = '0.946';
+  $POE::Component::Client::HTTP::VERSION = '0.947';
 }
 # vim: ts=2 sw=2 expandtab
 
@@ -15,7 +15,10 @@ use constant DEBUG_DATA => 0;
 use Carp qw(croak);
 use HTTP::Response;
 use Net::HTTP::Methods;
-use Socket qw(sockaddr_in inet_ntoa);
+use Socket qw(
+  sockaddr_in inet_ntoa
+  getnameinfo NI_NUMERICHOST NI_NUMERICSERV
+);
 
 use POE::Component::Client::HTTP::RequestFactory;
 use POE::Component::Client::HTTP::Request qw(:states :fields);
@@ -30,8 +33,6 @@ BEGIN {
   };
 }
 
-use Socket::GetAddrInfo qw(:newapi getnameinfo NI_NUMERICHOST NI_NUMERICSERV);
-
 use POE qw(
   Driver::SysRW Filter::Stream
   Filter::HTTPHead Filter::HTTPChunk
@@ -632,14 +633,17 @@ sub _poco_weeble_io_read {
   DEBUG_DATA and warn (ref($input) ? $input->as_string : _hexdump($input));
 
   # There was no corresponding request?  Nothing left to do here.
-  # We might have got here because the server sent EOF after we were done processing
-  # the request, and deleted it from our cache. ( notes for RT#50231 )
+  #
+  # We might have got here because the server sent EOF after we were
+  # done processing the request, and deleted it from our cache. (
+  # notes for RT#50231 )
   return unless defined $request_id;
 
   my $request = $heap->{request}->{$request_id};
   return unless defined $request;
   DEBUG and warn(
-    "REQUEST $request_id is $request <" . $request->[REQ_HTTP_REQUEST]->uri . ">"
+    "REQUEST $request_id is $request <",
+    $request->[REQ_HTTP_REQUEST]->uri(), ">"
   );
 
   # Reset the timeout if we get data.
@@ -829,7 +833,7 @@ sub _poco_weeble_io_read {
       # $request->close_connection;
     }
     else {
-      my $is_done = $request->add_content ($input);
+      $request->add_content($input);
     }
   }
 
@@ -1052,7 +1056,7 @@ POE::Component::Client::HTTP - a HTTP user-agent component
 
 =head1 VERSION
 
-version 0.946
+version 0.947
 
 =head1 SYNOPSIS
 
